/***************************************************************************//*!
\file ccs.h
\brief File ccs.h contains declaration of all external data structures.

### Description

    PackageName [ccs]
    Synopsis    [Package 'ccs' provides an extended CCS parser.]

    FileName    [ccs.h]
    Revision    [$Revision: 188 $]
    Date        [$Date: 2019-02-07 15:11:19 +0100 (čet, 07 feb 2019) $]
    Authors     [Robert Meolic (robert@meolic.com)]

### Copyright

This file is part of EST (Efficient Symbolic Tools).
Copyright (C) 2003, 2019 UM FERI, Koroska cesta 46, SI-2000 Maribor, Slovenia

EST is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation;
either version 2 of the License, or (at your option) any later version.

EST is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
Street, Fifth Floor, Boston, MA 02110-1301 USA.

### More info

See also: ccsInt.h

*******************************************************************************/

#ifndef _CCS
#define _CCS

#include <est.h>
#include <bdd.h>
#include <pa.h>
#include <versis.h>
#include <mc.h>
#include <strucval.h>

/* ON WIN32 THERE HAS TO BE DEFINED ESTWIN32 */
/* ON UNIX THERE HAS TO BE DEFINED ESTUNIX */
/* ON MACOSX THERE HAS TO BE DEFINED ESTMACOSX */

#ifdef ESTUNIX
#  ifndef EXTERN
#    define EXTERN extern
#  endif
#  ifndef DATAEXTERN
#    define DATAEXTERN extern
#  endif
#endif

#ifdef ESTMACOSX
#  ifndef EXTERN
#    define EXTERN extern
#  endif
#  ifndef DATAEXTERN
#    define DATAEXTERN extern
#  endif
#endif

#ifdef ESTWIN32
#  ifdef TCL
#    undef EXTERN
#    define EXTERN extern
#    undef DATAEXTERN
#    define DATAEXTERN extern
#  else
#    if defined(BUILD_EST) || defined(BUILD_CCS)
#      undef EXTERN
#      define EXTERN __declspec (dllexport)
#      undef DATAEXTERN
#      define DATAEXTERN extern __declspec (dllexport)
#    else
#      if defined(USE_EST) || defined(USE_CCS)
#        undef EXTERN
#        define EXTERN __declspec (dllimport)
#        undef DATAEXTERN
#        define DATAEXTERN __declspec (dllimport)
#      else
#        undef EXTERN
#        define EXTERN extern
#        undef DATAEXTERN
#        define DATAEXTERN extern
#      endif
#    endif
#  endif
#endif

/*----------------------------------------------------------------------------*/
/* Constant definitions                                                       */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Macro definitions                                                          */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Type declarations                                                          */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Variable declarations                                                      */
/*----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#endif

DATAEXTERN int ccs_status;

#ifdef __cplusplus
}
#endif

/*----------------------------------------------------------------------------*/
/* Prototypes for functions exported from ccsMain.c                           */
/*----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#endif

EXTERN void Ccs_InitPkg();

EXTERN void Ccs_ExitPkg();

EXTERN void Ccs_AboutPkg();

EXTERN int Ccs_ParseCCS(Est_String f, Est_Boolean q);

#ifdef __cplusplus
}
#endif

#endif /* _CCS */

