/***************************************************************************//*!
\file versis.h
\brief File versis.h contains declaration of all external data structures.

### Description

    PackageName [versis]
    Synopsis    [Package 'versis' provides basic tools for formal
                 verification of concurrent systems]

    FileName    [versis.h]
    Revision    [$Revision: 188 $]
    Date        [$Date: 2019-02-07 15:11:19 +0100 (čet, 07 feb 2019) $]
    Authors     [Robert Meolic (robert@meolic.com),
                 Mirjam Sepesy Maucec (mirjam.sepesy@um.si),
                 Tatjana Kapus (tatjana.kapus@um.si)]

### Copyright

This file is part of EST (Efficient Symbolic Tools).
Copyright (C) 2003, 2019 UM FERI, Koroska cesta 46, SI-2000 Maribor, Slovenia

EST is free software; you can redistribute it and/or modify it under the terms
of the GNU General Public License as published by the Free Software Foundation;
either version 2 of the License, or (at your option) any later version.

EST is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
PURPOSE. See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License along with
this program; if not, write to the Free Software Foundation, Inc., 51 Franklin
Street, Fifth Floor, Boston, MA 02110-1301 USA.

### More info

See also: versisInt.h

*******************************************************************************/

#ifndef _VERSIS
#define _VERSIS

#include <est.h>
#include <bdd.h>
#include <pa.h>

/* ON WIN32 THERE HAS TO BE DEFINED ESTWIN32 */
/* ON UNIX THERE HAS TO BE DEFINED ESTUNIX */
/* ON MACOSX THERE HAS TO BE DEFINED ESTMACOSX */

#ifdef ESTUNIX
#  ifndef EXTERN
#    define EXTERN extern
#  endif
#  ifndef DATAEXTERN
#    define DATAEXTERN extern
#  endif
#endif

#ifdef ESTMACOSX
#  ifndef EXTERN
#    define EXTERN extern
#  endif
#  ifndef DATAEXTERN
#    define DATAEXTERN extern
#  endif
#endif

#ifdef ESTWIN32
#  ifdef TCL
#    undef EXTERN
#    define EXTERN extern
#    undef DATAEXTERN
#    define DATAEXTERN extern
#  else
#    if defined(BUILD_EST) || defined(BUILD_VERSIS)
#      undef EXTERN
#      define EXTERN __declspec (dllexport)
#      undef DATAEXTERN
#      define DATAEXTERN extern __declspec (dllexport)
#    else
#      if defined(USE_EST) || defined(USE_VERSIS)
#        undef EXTERN
#        define EXTERN __declspec (dllimport)
#        undef DATAEXTERN
#        define DATAEXTERN __declspec (dllimport)
#      else
#        undef EXTERN
#        define EXTERN extern
#        undef DATAEXTERN
#        define DATAEXTERN extern
#      endif
#    endif
#  endif
#endif

/*----------------------------------------------------------------------------*/
/* Constant definitions                                                       */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Macro definitions                                                          */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Type declarations                                                          */
/*----------------------------------------------------------------------------*/

/*----------------------------------------------------------------------------*/
/* Variable declarations                                                      */
/*----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#endif

DATAEXTERN int versis_status;

#ifdef __cplusplus
}
#endif

/*----------------------------------------------------------------------------*/
/* Prototypes for functions exported from versisMain.c                        */
/*----------------------------------------------------------------------------*/

#ifdef __cplusplus
extern "C" {
#endif

EXTERN void Versis_InitPkg();

EXTERN void Versis_ExitPkg();

EXTERN void Versis_AboutPkg();

EXTERN void Versis_Compose(Est_String name, int type,
              Est_String process, Est_String actions, Est_Boolean onthefly);

EXTERN void Versis_ComposeInit(int numcomp);

EXTERN int Versis_ComposeStep(int numcomp, int N);

EXTERN void Versis_ComposeFinish(int numcomp);

EXTERN Est_Boolean Versis_Equivalence(int type, int par1, Est_String name1,
                                      int par2, Est_String name2);

EXTERN int Versis_Minimization(int type, int par, Est_String name);

EXTERN void Versis_ChangeRename(Est_String process, Est_String name1,
                                Est_String name2);

EXTERN void Versis_ChangeHide(Est_String process, Est_String name1);

EXTERN void Versis_ChangeForbid(Est_String process, Est_String name1);

EXTERN Bdd_Edge Versis_CheckDeadlock(Bdd_Edge D);

EXTERN Bdd_Edge Versis_CheckDivergence(Bdd_Edge D, Bdd_Edge tau);

#ifdef __cplusplus
}
#endif

#endif /* _VERSIS */

