/* *****************************************************************
PROFILING
****************************************************************** */

/* YOU HAVE TO PREPARE EST LIBRARY (e.g. make locallib) AND THEN COMPILE WITH:*/
/* make OR make static OR */
/* gcc -O2 -DESTUNIX -I../../bin -o crossing crossing.c -L../../bin -lest2 -L/home/meolic/est/biddy/bin -lbiddy -lgmp -lpthread -lm */

#include <time.h>

#include <bdd.h>
#include <pa.h>
#include <versis.h>
#include <mc.h>
#include <strucval.h>
#include <ccs.h>

int main(int argc, char **argv)
{
  clock_t elapsedtime,totaltime;

  setbuf(stdout, NULL);

  Bdd_InitPkg();
  Pa_InitPkg();
  Versis_InitPkg();
  Mc_InitPkg();
  Strucval_InitPkg();
  Ccs_InitPkg();

  if (argc == 1) {
    Bdd_SetManagerParameters(-1,-1,-1,-1,-1,-1,-1,-1,-1,-1);
  }
  else if (argc == 7) {
    int gcr,gcrF,gcrX;
    int rr,rrF,rrX;
    sscanf(argv[1],"%d",&gcr);
    sscanf(argv[2],"%d",&gcrF);
    sscanf(argv[3],"%d",&gcrX);
    sscanf(argv[4],"%d",&rr);
    sscanf(argv[5],"%d",&rrF);
    sscanf(argv[6],"%d",&rrX);
    Bdd_SetManagerParameters(gcr/100.0,gcrF/100.0,gcrX/100.0,rr/100.0,rrF/100.0,rrX/100.0,-1,-1,-1,-1);
    fprintf(stderr,"%d, %d, %d, %d, %d, %d, ",gcr,gcrF,gcrX,rr,rrF,rrX);
  }
  else if (argc == 11) {
    int gcr,gcrF,gcrX;
    int rr,rrF,rrX;
    int st;
    int fst;
    int cst;
    int fcst;
    sscanf(argv[1],"%d",&gcr);
    sscanf(argv[2],"%d",&gcrF);
    sscanf(argv[3],"%d",&gcrX);
    sscanf(argv[4],"%d",&rr);
    sscanf(argv[5],"%d",&rrF);
    sscanf(argv[6],"%d",&rrX);
    sscanf(argv[7],"%d",&st);
    sscanf(argv[8],"%d",&fst);
    sscanf(argv[9],"%d",&cst);
    sscanf(argv[10],"%d",&fcst);
    Bdd_SetManagerParameters(gcr/100.0,gcrF/100.0,gcrX/100.0,rr/100.0,rrF/100.0,rrX/100.0,st/100.0,fst/100.0,cst/100.0,fcst/100.0);
    fprintf(stderr,"%d, %d, %d, %d, %d, %d, ",gcr,gcrF,gcrX,rr,rrF,rrX);
  }
  else {
    printf("Wrong number of parameters!\n");
    exit(0);
  }

  /* compare this function with ../../data/crossing/crossing.tcl */
  elapsedtime = clock();
  Ccs_ParseCCS("../../data/crossing/crossing2.ccs",TRUE);
  elapsedtime = clock()-elapsedtime;
  totaltime = elapsedtime;
  printf("\n");
  fprintf(stderr,"%u, %u, %u, %u GC, ",Bdd_Stat_NodeTableSize(),Bdd_Stat_NodeTableGenerated(),Bdd_Stat_NodeTableMax(),Bdd_Stat_NodeTableGCNumber());
#ifdef MINGW
  fprintf(stderr,"%I64u B, ",Bdd_Stat_ReadMemoryInUse());
#else
  fprintf(stderr,"%llu B, ",Bdd_Stat_ReadMemoryInUse());
  fprintf(stderr,"%.2f sec CCS, ",elapsedtime/(1.0*CLOCKS_PER_SEC));
#endif
  /*
  printf("\n\n");
  Bdd_SystemStat(stdout);
  */
  printf("\n");
  Mc_ReadACTLFile("../../data/crossing/crossing.actl");
  elapsedtime = clock();
  /**/
  Mc_CheckACTL(1,"SW6","F9",0);
  Mc_CheckACTL(1,"SW6","F10X6",0);
  /**/
  /*
  Mc_CheckACTL(1,"SW8","F10X8",0);
  */
  elapsedtime = clock()-elapsedtime;
  totaltime += elapsedtime;
  printf("\n");
  fprintf(stderr,"%u, %u, %u, %u GC, ",Bdd_Stat_NodeTableSize(),Bdd_Stat_NodeTableGenerated(),Bdd_Stat_NodeTableMax(),Bdd_Stat_NodeTableGCNumber());
#ifdef MINGW
  fprintf(stderr,"%I64u B, ",Bdd_Stat_ReadMemoryInUse());
#else
  fprintf(stderr,"%llu B, ",Bdd_Stat_ReadMemoryInUse());
  fprintf(stderr,"%.2f MC, ",elapsedtime/(1.0*CLOCKS_PER_SEC));
  fprintf(stderr,"%.2f CCS+MC, ",totaltime/(1.0*CLOCKS_PER_SEC));
#endif
  /*
  printf("\n\n");
  Bdd_SystemStat(stdout);
  */
  printf("\n");

  Ccs_ExitPkg();
  Strucval_ExitPkg();
  Mc_ExitPkg();
  Versis_ExitPkg();
  Pa_ExitPkg();
  Bdd_ExitPkg();

  return(0);
}
