/* *****************************************************************
Demo program to check installation.
****************************************************************** */

/*
# For local debugging and profiling:
# biddy> make profile "BINDIR = ./bin"
# est-2ed/source> make locallib (UNCOMMENT DEBUG+PROFILE IN MAKEFILE.LINUX)
# est-2ed/projects/demo> make local
# est-2ed/projects/demo> ./demo
# est-2ed/projects/demo> gprof demo gmon.out > analysis.txt
*/

#include <bdd.h>
#include <pa.h>
#include <versis.h>
#include <mc.h>
#include <strucval.h>
#include <ccs.h>

#define DOPROFILE

static void test1();
static void test2();
static void test3();

void hello() {
  printf("=======================================================================\n");
  printf("   Demo program from EST project.\n");
  printf("=======================================================================\n");
}

int main(int argc, char **argv)
{
  setbuf(stdout, NULL);

  hello();

  Bdd_InitPkg();
  Pa_InitPkg();
  Versis_InitPkg();
  Mc_InitPkg();
  Strucval_InitPkg();
  Ccs_InitPkg();

  Bdd_AboutPkg();
  Pa_AboutPkg();
  Versis_AboutPkg();
  Mc_AboutPkg();
  Strucval_AboutPkg();
  Ccs_AboutPkg();

#ifdef DOPROFILE
  if (argc == 1) {
    Bdd_SetManagerParameters(-1,-1,-1,-1,-1,-1,-1,-1,-1,-1);
  }
  else if (argc == 7) {
    int gcr,gcrF,gcrX;
    int rr,rrF,rrX;
    sscanf(argv[1],"%d",&gcr);
    sscanf(argv[2],"%d",&gcrF);
    sscanf(argv[3],"%d",&gcrX);
    sscanf(argv[4],"%d",&rr);
    sscanf(argv[5],"%d",&rrF);
    sscanf(argv[6],"%d",&rrX);
    Bdd_SetManagerParameters(gcr/100.0,gcrF/100.0,gcrX/100.0,rr/100.0,rrF/100.0,rrX/100.0,-1,-1,-1,-1);
  }
  else if (argc == 11) {
    int gcr,gcrF,gcrX;
    int rr,rrF,rrX;
    int st;
    int fst;
    int cst;
    int fcst;
    sscanf(argv[1],"%d",&gcr);
    sscanf(argv[2],"%d",&gcrF);
    sscanf(argv[3],"%d",&gcrX);
    sscanf(argv[4],"%d",&rr);
    sscanf(argv[5],"%d",&rrF);
    sscanf(argv[6],"%d",&rrX);
    sscanf(argv[7],"%d",&st);
    sscanf(argv[8],"%d",&fst);
    sscanf(argv[9],"%d",&cst);
    sscanf(argv[10],"%d",&fcst);
    Bdd_SetManagerParameters(gcr/100.0,gcrF/100.0,gcrX/100.0,rr/100.0,rrF/100.0,rrX/100.0,st/100.0,fst/100.0,cst/100.0,fcst/100.0);
  }
  else {
    printf("Wrong number of parameters!\n");
    exit(0);
  }
  printf("\n");
#endif

  /* THIS PART IS FOR DEBUGGING */
  /* test1(); */

  /* THIS PART IS FOR PROFILING */
  /* test2(); */

  /* THIS PART IS FOR PROFILING */
  test3();

  Ccs_ExitPkg();
  Strucval_ExitPkg();
  Mc_ExitPkg();
  Versis_ExitPkg();
  Pa_ExitPkg();
  Bdd_ExitPkg();

  printf("Demo finished.\n");

  return(0);
}

/* ******************************************************* */
/* LOCAL FUNCTIONS - it is a good idea to make them static */
/* ******************************************************* */

static void
test1()
{
  Bdd_Edge f,g;

  f = Bdd_Eval1("(AND X Y)");
  Bdd_SaveFormula(NULL,"F",f);
  Bdd_WriteTable("F");

  g = Bdd_Eval1("(OR F (AND V W))");
  Bdd_SaveFormula(NULL,"G",g);
  Bdd_WriteBDD("G");
}

static void
test2()
{
  /* compare this function with ../../data/filozofi/philo-test.tcl */

  Pa_ParseSortProcess("../../data/filozofi/philo5.dat");
  Pa_EncodeMultiProcesses("FLZF1 VLC1 FLZF2 VLC2 FLZF3 VLC3 FLZF4 VLC4 FLZF5 VLC5",NULL);
  printf("REPORT BEFORE Versis_Compose\n"); Bdd_SystemStat(NULL);
  Versis_Compose("S",1,
                 "FLZF1 VLC1 FLZF2 VLC2 FLZF3 VLC3 FLZF4 VLC4 FLZF5 VLC5",
                 "think1 think2 think3 think4 think5 eat1 eat2 eat3 eat4 eat5",
                 FALSE);
  printf("REPORT AFTER Versis_Compose\n"); Bdd_SystemStat(NULL);
  Ccs_ParseCCS("../../data/filozofi/philo5dat-v1.ccs",TRUE);
  Ccs_ParseCCS("../../data/filozofi/philo5dat-v2.ccs",TRUE);
  printf("REPORT AFTER BOTH Ccs_ParseCCS\n"); Bdd_SystemStat(NULL);
  printf("STARTED FIRST EQUIVALENCE CHECKING, PLEASE WAIT...\n");  
  if (Versis_Equivalence(0,0,"S1",1,"S")) {
    printf("S1 is strong equivalent to S\n");  
  } else {    
    printf("S1 is not strong equivalent to S\n");  
  }
  printf("REPORT AFTER FIRST Versis_Equivalence\n"); Bdd_SystemStat(NULL);
  printf("STARTED SECOND EQUIVALENCE CHECKING, PLEASE WAIT...\n");  
  if (Versis_Equivalence(0,0,"S2",1,"S")) {
    printf("S2 is strong equivalent to S\n");  
  } else {    
    printf("S2 is not strong equivalent to S\n");  
  }
  printf("REPORT AFTER SECOND Versis_Equivalence\n"); Bdd_SystemStat(NULL);
  printf("STARTED THIRD EQUIVALENCE CHECKING, PLEASE WAIT...\n");  
  if (Versis_Equivalence(0,0,"S1",0,"S2")) {
    printf("S1 is strong equivalent to S2\n");  
  } else {    
    printf("S1 is not strong equivalent to S2\n");  
  }
  printf("REPORT AFTER THIRD Versis_Equivalence\n"); Bdd_SystemStat(NULL);
}

static void
test3()
{
  /* compare this function with ../../data/crossing/crossing.tcl */
  Mc_ReadACTLFile("../../data/crossing/crossing.actl");
  Ccs_ParseCCS("../../data/crossing/crossing2.ccs",TRUE);
/*
  Bdd_SystemStat(stdout);
  Mc_CheckACTL(1, "SW4", "F13", 0);
  Bdd_SystemStat(stdout);
*/
  fprintf(stderr,"%u, %u, %u, ",Bdd_Stat_NodeTableSize(),Bdd_Stat_NodeTableMax(),Bdd_Stat_NodeTableGCNumber());
/*
  fprintf(stderr,"#%2u, ",Bdd_Stat_NodeTableGCNumber());
#ifdef MINGW
  fprintf(stderr,"%I64u, ",Bdd_Stat_ReadMemoryInUse());
#else
  fprintf(stderr,"%llu, ",Bdd_Stat_ReadMemoryInUse());
#endif
*/
}
